@@ -10,19 +10,23 @@ class Dashboard:
     def __init__(self, py_client, dashboard_json):
         self._dashboard_json = dashboard_json
         self._py_client = py_client
-        
+
     def _reset(self):
         self._dashboard_json = self._py_client.connector.rest_call('get', 'api/v1/dashboards/{}'.format(self.get_id()))
-        
+
+    def get_json(self):
+        """Returns dashboard json"""
+        return self._dashboard_json
+
     def get_datasource(self):
-        """Returns the elasticube powering the dashboard.  
-        
-        Not reliable when multiple elasticubes on dashboard.  
+        """Returns the elasticube powering the dashboard.
+
+        Not reliable when multiple elasticubes on dashboard.
         """
         return self._py_client.get_elasticube_by_name(self._dashboard_json['datasource']['title'])
 
     def get_id(self):
-        """Gets the dashboard's id"""   
+        """Gets the dashboard's id"""
         return self._dashboard_json['oid']
 
     def get_name(self):
@@ -39,7 +43,7 @@ class Dashboard:
         return_json = {'sharesTo': []}
         for share in resp_json['sharesTo']:
             share_json = {
-                'shareId': share['shareId'], 
+                'shareId': share['shareId'],
                 'type': share['type']
             }
             if 'rule' in share:
@@ -48,7 +52,7 @@ class Dashboard:
                 share_json['subscribe'] = share['subscribe']
             return_json['sharesTo'].append(share_json)
         return return_json
-    
+
     def get_share_users_groups(self):
         """Gets a list of users and groups the dashboard is shared with"""
         resp_json = self._py_client.connector.rest_call('get', 'api/shares/dashboard/{}'.format(self.get_id()))
@@ -61,21 +65,21 @@ class Dashboard:
         return ret_arr
 
     def add_share(self, share, rule, subscribe):
-        """Share a dashboard to a new group or user.    
-        
-        If dashboard is already shared with user or group, nothing happens  
-        
+        """Share a dashboard to a new group or user.
+
+        If dashboard is already shared with user or group, nothing happens
+
         Args:
-            share: A PySense Group or User  
-            rule: The permission of the user on the dashboard (view, edit, etc)  
-            subscribe: true or false, whether to subscribe the user to reports    
+            share: A PySense Group or User
+            rule: The permission of the user on the dashboard (view, edit, etc)
+            subscribe: true or false, whether to subscribe the user to reports
         """
         curr_shares = self.get_shares()
         share_id = share.get_id()
         for curr_share in curr_shares['sharesTo']:
             if 'shareId' == curr_share['shareId']:
                 share_id = None
-        
+
         if share_id is not None:
             if isinstance(share, PySenseUser.User):
                 curr_shares['sharesTo'].append(
@@ -85,10 +89,10 @@ class Dashboard:
                 curr_shares['sharesTo'].append(
                     {'shareId': share.get_id(), 'type': 'group', 'rule': rule, 'subscribe': subscribe}
                 )
-        
-        self._py_client.connector.rest_call('post', 'api/shares/dashboard/{}'.format(self.get_id()), 
+
+        self._py_client.connector.rest_call('post', 'api/shares/dashboard/{}'.format(self.get_id()),
                                             json_payload=curr_shares)
-        
+
     def remove_shares(self, shares):
         """Unshare a dashboard to a list of groups and users"""
         share_ids_to_delete = []
@@ -99,7 +103,7 @@ class Dashboard:
             for i, shares in enumerate(current_shares['sharesTo']):
                 if shares['shareId'] == share_id:
                     del current_shares['sharesTo'][i]
-        self._py_client.connector.rest_call('post', 'api/shares/dashboard/{}'.format(self.get_id()), 
+        self._py_client.connector.rest_call('post', 'api/shares/dashboard/{}'.format(self.get_id()),
                                             json_payload=current_shares)
 
     def move_to_folder(self, folder):
@@ -111,21 +115,21 @@ class Dashboard:
         self._py_client.connector.rest_call('patch', 'api/v1/dashboards/{}'.format(self.get_id()),
                                             json_payload={'parentFolder': folder_oid})
         self._reset()
-    
+
     def export_to_png(self, *, path=None, include_title=None, include_filters=None, include_ds=None, width=None):
-        """Get dashboard as png    
-    
+        """Get dashboard as png
+
         Args:
-            path: (optional) Path to save location of png    
-            include_title: (optional) Should dashboard title be included in the exported file  
-            include_filters: (optional) Should dashboard filters be included in the exported file  
-            include_ds: (optional) Should dashboard data source info be included in the exported file  
-            width: (optional) Render width in pixels  
-            
+            path: (optional) Path to save location of png
+            include_title: (optional) Should dashboard title be included in the exported file
+            include_filters: (optional) Should dashboard filters be included in the exported file
+            include_ds: (optional) Should dashboard data source info be included in the exported file
+            width: (optional) Render width in pixels
+
         Returns:
-            The path of the created file if provided or else the raw response object  
+            The path of the created file if provided or else the raw response object
         """
-        
+
         query_params = {
             'includeTitle': include_title,
             'includeFilters': include_filters,
@@ -138,7 +142,7 @@ class Dashboard:
             with open(path, 'wb') as out_file:
                 out_file.write(resp_content)
             return path
-        else: 
+        else:
             return resp_content
 
     def export_to_pdf(self, paper_format, paper_orientation, layout, *, path=None,
@@ -146,27 +150,27 @@ class Dashboard:
                       preview=None,
                       row_count=None, show_title=None, show_footer=None, title=None, title_size=None,
                       title_position=None):
-        """Get dashboard as pdf   
-    
+        """Get dashboard as pdf
+
         Args:
-            paper_format: What paper format should be used while rendering the dashboard.  
-            paper_orientation: What paper orientation should be used while rendering the dashboard  
-            layout: What layout should be used while rendering the dashboard, as is or feed  
-            path: (optional) Path to save location of pdf  
-            include_title: (optional) Should dashboard title be included in the exported file  
-            include_filters: (optional) Should dashboard filters be included in the exported file  
-            include_ds: (optional) Should dashboard datasource info be included in the exported file  
-            widget_id: (optional) Widget Id (Use only for Table and Pivot Widgets)  
-            preview: (optional) Should use a new Pixel Perfect Reporting  
-            row_count: (optional) Count of Table/Pivot rows to export  
-            show_title: (optional) Should Table/Pivot Widget title be included in the exported file  
-            show_footer: (optional) Should Table/Pivot Widget footer be included in the exported file   
-            title: (optional) Table/Pivot Widget title text in the exported file  
-            title_size: (optional) Table/Pivot widget title size in the exported file  
-            title_position: (optional) Table/Pivot widget title position in the exported file  
-            
+            paper_format: What paper format should be used while rendering the dashboard.
+            paper_orientation: What paper orientation should be used while rendering the dashboard
+            layout: What layout should be used while rendering the dashboard, as is or feed
+            path: (optional) Path to save location of pdf
+            include_title: (optional) Should dashboard title be included in the exported file
+            include_filters: (optional) Should dashboard filters be included in the exported file
+            include_ds: (optional) Should dashboard datasource info be included in the exported file
+            widget_id: (optional) Widget Id (Use only for Table and Pivot Widgets)
+            preview: (optional) Should use a new Pixel Perfect Reporting
+            row_count: (optional) Count of Table/Pivot rows to export
+            show_title: (optional) Should Table/Pivot Widget title be included in the exported file
+            show_footer: (optional) Should Table/Pivot Widget footer be included in the exported file
+            title: (optional) Table/Pivot Widget title text in the exported file
+            title_size: (optional) Table/Pivot widget title size in the exported file
+            title_position: (optional) Table/Pivot widget title position in the exported file
+
         Returns:
-             The path of the created file if provided, else the raw content  
+             The path of the created file if provided, else the raw content
         """
         query_params = {
             'paperFormat': paper_format,
@@ -191,47 +195,47 @@ class Dashboard:
             with open(path, 'wb') as out_file:
                 out_file.write(resp_content)
             return path
-        else: 
+        else:
             return resp_content
 
     def export_to_dash(self, *, path=None):
-        """Get dashboard as dash file.   
-   
+        """Get dashboard as dash file.
+
         Args:
-            path: (optional) Path to save location of dash file  
-        
+            path: (optional) Path to save location of dash file
+
         Returns:
-            The path of the created file if path provided, else the raw content  
+            The path of the created file if path provided, else the raw content
         """
-        
+
         resp_content = self._py_client.connector.rest_call('get', 'api/v1/dashboards/{}/export/dash'
                                                            .format(self.get_id()), raw=True)
         if path is not None:
             with open(path, 'wb') as out_file:
                 out_file.write(resp_content)
             return path
-        else: 
+        else:
             return resp_content
 
     def get_widgets(self, *, title=None, type=None, subtype=None,
                     fields=None, sort=None, skip=None, limit=None):
-        """Returns an array of a dashboard’s widgets.  
-  
+        """Returns an array of a dashboard’s widgets.
+
         Args:
-            title: (optional) Widget title to filter by  
-            type: (optional) Widget type to filter by  
-            subtype: (optional) Widget sub-type to filter by  
-            fields: (optional) Whitelist of fields to return for each document. fields Can also define which fields to exclude  
-                by prefixing field names with -  
-            sort: (optional) Field by which the results should be sorted. Ascending by default, descending if prefixed by -  
-            skip: (optional) Number of results to skip from the start of the data set. skip is to be used with the limit  
-                parameter for paging  
-            limit: (optional) How many results should be returned. limit is to be used with the skip parameter for paging  
-          
+            title: (optional) Widget title to filter by
+            type: (optional) Widget type to filter by
+            subtype: (optional) Widget sub-type to filter by
+            fields: (optional) Whitelist of fields to return for each document. fields Can also define which fields to exclude
+                by prefixing field names with -
+            sort: (optional) Field by which the results should be sorted. Ascending by default, descending if prefixed by -
+            skip: (optional) Number of results to skip from the start of the data set. skip is to be used with the limit
+                parameter for paging
+            limit: (optional) How many results should be returned. limit is to be used with the skip parameter for paging
+
         Returns:
-            An array of widget objects  
+            An array of widget objects
         """
-        
+
         query_params = {
             'title': title,
             'type': type,
@@ -241,7 +245,7 @@ class Dashboard:
             'skip': skip,
             'limit': limit
         }
-        
+
         ret_arr = []
         resp_json = self._py_client.connector.rest_call('get', 'api/v1/dashboards/{}/widgets'.format(self.get_id()),
                                               query_params=query_params)
@@ -250,17 +254,17 @@ class Dashboard:
         return ret_arr
 
     def get_widget_by_id(self, widget_id, *, fields=None):
-        """Returns a specific widget (by ID) from a specific dashboard.  
-    
+        """Returns a specific widget (by ID) from a specific dashboard.
+
         Args:
-            widget_id: The ID of the widget to get   
-            fields: (optional) Whitelist of fields to return for each document.  
-                Fields Can also define which fields to exclude by prefixing field names with -   
-            
+            widget_id: The ID of the widget to get
+            fields: (optional) Whitelist of fields to return for each document.
+                Fields Can also define which fields to exclude by prefixing field names with -
+
         Returns:
-            A widget object   
+            A widget object
         """
-        
+
         query_params = {
             'fields': fields
         }
@@ -270,21 +274,21 @@ class Dashboard:
         return PySenseWidget.Widget(self._py_client, resp_json)
 
     def add_widget(self, widget):
-        """Adds the provided widget object to the dashboard.  
+        """Adds the provided widget object to the dashboard.
 
         Args:
-            widget: PySenseWidget.Widget object to add   
-          
+            widget: PySenseWidget.Widget object to add
+
         Returns:
-            The widget added to the dashboard    
+            The widget added to the dashboard
         """
-        
+
         resp_json = self._py_client.connector.rest_call('post', 'api/v1/dashboards/{}/widgets'.format(self.get_id()),
-                                              json_payload=widget.get_widget_json())
+                                                        json_payload=widget.get_json())
         return PySenseWidget.Widget(self._py_client, resp_json)
 
     def delete_widget(self, widgets):
-        """Deletes widgets from it’s dashboard."""  
+        """Deletes widgets from it’s dashboard."""
         for widget in PySenseUtils.make_iterable(widgets):
             self._py_client.connector.rest_call('delete', 'api/v1/dashboards/{}/widgets/{}'
                                                 .format(self.get_id(), widget.get_id()))
@@ -311,7 +315,7 @@ class Dashboard:
                     patch_json['layout']['columns'].pop(n)
         self._py_client.connector.rest_call('patch', 'api/v1/dashboards/{}'.format(self.get_id()), json_payload=patch_json)
         self._reset()
-        
+
     def does_widget_exist(self, widget_id):
         """Returns true or false if the widget with id is in the dashboard"""
         try:
